@@ -111,9 +111,6 @@ class Database(object):
         self.close()
 
     def clean(self):
-        '''
-        close and remove hdf5 file
-        '''
         self.__exit__()
         try:
             os.remove(self.filename)
@@ -722,30 +719,28 @@ class DatabaseFromOMA(Database):
             # compute most ancestral taxon; when absent, flag it with 1000000
             tax_levels = list(map(lambda x: tax2level.get(x, 1000000), curr_oma_taxa))
             min_level = min(tax_levels)
-
+            
+            # skip HOGs outside of taxonomic scope defined by the root-taxon
             if min_level == 1000000:
-                tax = None
+                return fam, curr_oma_roothog
             else:
-                tax = curr_oma_taxa[tax_levels.index(min_level)]
+                tax = curr_oma_taxa[tax_levels.index(min_level)]  
+                
+                # whether HOG is descendant of current OMA root-HOG 
+                if _is_descendant(curr_oma_hog, curr_oma_roothog):
 
-            # store if descendant of current OMA root-HOG
-            if _is_descendant(curr_oma_hog, curr_oma_roothog):
-
-                _store(
-                    fam,
-                    curr_oma_hog,
-                    curr_oma_roothog,
-                    fam2hogs,
-                    hog2oma_hog,
-                    hog2tax,
-                    tax,
-                )
-
-            # if tax equal or younger that root taxon: store, update fam and current OMA root-HOG
-            elif tax:
-
-                # include only family at root-taxon if include_younger_fams==False
-                if (not include_younger_fams and tax == roottax) or include_younger_fams:
+                    _store(
+                        fam,
+                        curr_oma_hog,
+                        curr_oma_roothog,
+                        fam2hogs,
+                        hog2oma_hog,
+                        hog2tax,
+                        tax,
+                    )
+                
+                # or create a new family (include only family at root-taxon if include_younger_fams==False)
+                elif (not include_younger_fams and tax == roottax) or include_younger_fams:
 
                     fam += 1
                     curr_oma_roothog = curr_oma_hog
@@ -762,6 +757,50 @@ class DatabaseFromOMA(Database):
                     )
 
             return fam, curr_oma_roothog
+            
+            # # compute most ancestral taxon; when absent, flag it with 1000000
+            # tax_levels = list(map(lambda x: tax2level.get(x, 1000000), curr_oma_taxa))
+            # min_level = min(tax_levels)
+
+            # if min_level == 1000000:
+            #     tax = None
+            # else:
+            #     tax = curr_oma_taxa[tax_levels.index(min_level)]
+
+            # # store if descendant of current OMA root-HOG
+            # if _is_descendant(curr_oma_hog, curr_oma_roothog):
+
+            #     _store(
+            #         fam,
+            #         curr_oma_hog,
+            #         curr_oma_roothog,
+            #         fam2hogs,
+            #         hog2oma_hog,
+            #         hog2tax,
+            #         tax,
+            #     )
+
+            # # if tax equal or younger that root taxon: store, update fam and current OMA root-HOG
+            # elif tax:
+
+            #     # include only family at root-taxon if include_younger_fams==False
+            #     if (not include_younger_fams and tax == roottax) or include_younger_fams:
+
+            #         fam += 1
+            #         curr_oma_roothog = curr_oma_hog
+
+            #         # store after updating fam
+            #         _store(
+            #             fam,
+            #             curr_oma_hog,
+            #             curr_oma_roothog,
+            #             fam2hogs,
+            #             hog2oma_hog,
+            #             hog2tax,
+            #             tax,
+            #         )
+
+            # return fam, curr_oma_roothog
 
         def _process_oma_fam(
             fam_tab_sort, tax2level, fam, fam2hogs, hog2oma_hog, hog2tax, roottax, include_younger_fams
